@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import contextlib
 import os
 from datetime import datetime, timezone
@@ -217,6 +219,7 @@ def generate(
     class_name: Optional[str] = None,
     use_standard_collections: bool = False,
     use_schema_description: bool = False,
+    use_field_description: bool = False,
     reuse_model: bool = False,
     encoding: str = 'utf-8',
     enum_field_as_literal: Optional[LiteralType] = None,
@@ -341,6 +344,7 @@ def generate(
         if isinstance(input_, Path) and input_.is_file()
         else None,
         use_schema_description=use_schema_description,
+        use_field_description=use_field_description,
         reuse_model=reuse_model,
         enum_field_as_literal=enum_field_as_literal,
         set_default_enum_member=set_default_enum_member,
