@@ -4,6 +4,8 @@
 Main function.
 """
 
+from __future__ import annotations
+
 import json
 import locale
 import signal
@@ -243,6 +245,13 @@ arg_parser.add_argument(
     default=None,
 )
 
+arg_parser.add_argument(
+    '--use-field-description',
+    help='Use schema description to populate field docstring',
+    action='store_true',
+    default=None,
+)
+
 arg_parser.add_argument(
     '--reuse-model',
     help='Re-use models on the field when a module has the model with the same content',
@@ -454,6 +463,7 @@ class Config(BaseModel):
     class_name: Optional[str] = None
     use_standard_collections: bool = False
     use_schema_description: bool = False
+    use_field_description: bool = False
     reuse_model: bool = False
     encoding: str = 'utf-8'
     enum_field_as_literal: Optional[LiteralType] = None
@@ -527,6 +537,14 @@ def main(args: Optional[Sequence[str]] = None) -> Exit:
         print(e.message, file=sys.stderr)
         return Exit.ERROR
 
+    if not config.input and not config.url and sys.stdin.isatty():
+        print(
+            'Not Found Input: require `stdin` or arguments `--input` or `--url`',
+            file=sys.stderr,
+        )
+        arg_parser.print_help()
+        return Exit.ERROR
+
     if not is_supported_in_black(config.target_python_version):  # pragma: no cover
         print(
             f"Installed black doesn't support Python version {config.target_python_version.value}.\n"  # type: ignore
@@ -591,6 +609,7 @@ def main(args: Optional[Sequence[str]] = None) -> Exit:
             class_name=config.class_name,
             use_standard_collections=config.use_standard_collections,
             use_schema_description=config.use_schema_description,
+            use_field_description=config.use_field_description,
             reuse_model=config.reuse_model,
             encoding=config.encoding,
             enum_field_as_literal=config.enum_field_as_literal,
