@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from enum import Enum
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, Dict, Optional, Sequence
@@ -14,6 +16,7 @@ class PythonVersion(Enum):
     PY_38 = '3.8'
     PY_39 = '3.9'
     PY_310 = '3.10'
+    PY_311 = '3.11'
 
     @property
     def has_literal_type(self) -> bool:
