@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from abc import ABC, abstractmethod
 from collections import defaultdict
 from functools import lru_cache
@@ -49,6 +51,7 @@ class DataModelFieldBase(_BaseModel):
     extras: Dict[str, Any] = {}
     use_annotated: bool = False
     has_default: bool = False
+    use_field_description: bool = False
     _exclude_fields: ClassVar[Set[str]] = {'parent'}
     _pass_fields: ClassVar[Set[str]] = {'parent', 'data_type'}
 
@@ -92,6 +95,14 @@ class DataModelFieldBase(_BaseModel):
             imports.append((IMPORT_ANNOTATED,))
         return chain_as_tuple(*imports)
 
+    @property
+    def docstring(self) -> Optional[str]:
+        if self.use_field_description:
+            description = self.extras.get('description', None)
+            if description is not None:
+                return f'{description}'
+        return None
+
     @property
     def unresolved_types(self) -> FrozenSet[str]:
         return self.data_type.unresolved_types
@@ -281,7 +292,7 @@ class DataModel(TemplateBase, ABC):
         return get_module_name(self.name, self.file_path)
 
     @property
-    def all_data_types(self) -> Iterator['DataType']:
+    def all_data_types(self) -> Iterator[DataType]:
         for field in self.fields:
             yield from field.data_type.all_data_types
         yield from self.base_classes
