@@ -1,9 +1,12 @@
+from __future__ import annotations
+
 import enum as _enum
 from collections import defaultdict
 from contextlib import contextmanager
 from functools import lru_cache
 from pathlib import Path
 from typing import (
+    TYPE_CHECKING,
     Any,
     Callable,
     ClassVar,
@@ -160,7 +163,7 @@ class JsonSchemaObject(BaseModel):
             return value.replace('#', '#/')
         return value
 
-    items: Union[List['JsonSchemaObject'], 'JsonSchemaObject', None]
+    items: Union[List[JsonSchemaObject], JsonSchemaObject, None]
     uniqueItems: Optional[bool]
     type: Union[str, List[str], None]
     format: Optional[str]
@@ -174,14 +177,14 @@ class JsonSchemaObject(BaseModel):
     multipleOf: Optional[float]
     exclusiveMaximum: Union[float, bool, None]
     exclusiveMinimum: Union[float, bool, None]
-    additionalProperties: Union['JsonSchemaObject', bool, None]
-    patternProperties: Optional[Dict[str, 'JsonSchemaObject']]
-    oneOf: List['JsonSchemaObject'] = []
-    anyOf: List['JsonSchemaObject'] = []
-    allOf: List['JsonSchemaObject'] = []
+    additionalProperties: Union[JsonSchemaObject, bool, None]
+    patternProperties: Optional[Dict[str, JsonSchemaObject]]
+    oneOf: List[JsonSchemaObject] = []
+    anyOf: List[JsonSchemaObject] = []
+    allOf: List[JsonSchemaObject] = []
     enum: List[Any] = []
     writeOnly: Optional[bool]
-    properties: Optional[Dict[str, Union['JsonSchemaObject', bool]]]
+    properties: Optional[Dict[str, Union[JsonSchemaObject, bool]]]
     required: List[str] = []
     ref: Optional[str] = Field(default=None, alias='$ref')
     nullable: Optional[bool] = False
@@ -193,15 +196,17 @@ class JsonSchemaObject(BaseModel):
     default: Any
     id: Optional[str] = Field(default=None, alias='$id')
     custom_type_path: Optional[str] = Field(default=None, alias='customTypePath')
-    extras: Dict[str, Any] = Field(default=None, alias=__extra_key__)
+    extras: Dict[str, Any] = Field(alias=__extra_key__, default_factory=dict)
 
     class Config:
         arbitrary_types_allowed = True
         keep_untouched = (cached_property,)
 
-    def __init__(self, **data: Any) -> None:  # type: ignore
-        super().__init__(**data)
-        self.extras = {k: v for k, v in data.items() if k not in EXCLUDE_FIELD_KEYS}
+    if not TYPE_CHECKING:
+
+        def __init__(self, **data: Any) -> None:
+            super().__init__(**data)
+            self.extras = {k: v for k, v in data.items() if k not in EXCLUDE_FIELD_KEYS}
 
     @cached_property
     def is_object(self) -> bool:
@@ -313,6 +318,7 @@ class JsonSchemaParser(Parser):
         use_standard_collections: bool = False,
         base_path: Optional[Path] = None,
         use_schema_description: bool = False,
+        use_field_description: bool = False,
         reuse_model: bool = False,
         encoding: str = 'utf-8',
         enum_field_as_literal: Optional[LiteralType] = None,
@@ -361,6 +367,7 @@ class JsonSchemaParser(Parser):
             use_standard_collections=use_standard_collections,
             base_path=base_path,
             use_schema_description=use_schema_description,
+            use_field_description=use_field_description,
             reuse_model=reuse_model,
             encoding=encoding,
             enum_field_as_literal=enum_field_as_literal,
@@ -555,6 +562,7 @@ class JsonSchemaParser(Parser):
                         alias=alias,
                         strip_default_none=self.strip_default_none,
                         use_annotated=self.use_annotated,
+                        use_field_description=self.use_field_description,
                     )
                 )
                 continue
@@ -596,6 +604,7 @@ class JsonSchemaParser(Parser):
                     strip_default_none=self.strip_default_none,
                     extras={**self.get_field_extras(field)},
                     use_annotated=self.use_annotated,
+                    use_field_description=self.use_field_description,
                 )
             )
         return fields
@@ -817,6 +826,7 @@ class JsonSchemaParser(Parser):
             strip_default_none=self.strip_default_none,
             extras=self.get_field_extras(obj),
             use_annotated=self.use_annotated,
+            use_field_description=self.use_field_description,
         )
 
     def parse_array(
@@ -851,6 +861,7 @@ class JsonSchemaParser(Parser):
                 strip_default_none=field.strip_default_none,
                 extras=field.extras,
                 use_annotated=self.use_annotated,
+                use_field_description=self.use_field_description,
             )
 
         data_model_root = self.data_model_root_type(
@@ -927,6 +938,7 @@ class JsonSchemaParser(Parser):
                     strip_default_none=self.strip_default_none,
                     extras=self.get_field_extras(obj),
                     use_annotated=self.use_annotated,
+                    use_field_description=self.use_field_description,
                 )
             ],
             custom_base_class=self.base_class,
@@ -999,6 +1011,7 @@ class JsonSchemaParser(Parser):
                     required=True,
                     strip_default_none=self.strip_default_none,
                     has_default=obj.has_default,
+                    use_field_description=self.use_field_description,
                 )
             )
 
@@ -1052,6 +1065,7 @@ class JsonSchemaParser(Parser):
                     extras=self.get_field_extras(obj),
                     use_annotated=self.use_annotated,
                     has_default=obj.has_default,
+                    use_field_description=self.use_field_description,
                 )
             ],
             custom_base_class=self.base_class,
